@@ -25,6 +25,7 @@ import (
 	"github.com/weaveworks/eksctl/integration/utilities/kube"
 	api "github.com/weaveworks/eksctl/pkg/apis/eksctl.io/v1alpha5"
 	"github.com/weaveworks/eksctl/pkg/testutils"
+	"github.com/weaveworks/eksctl/pkg/utils/names"
 
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/client-go/kubernetes"
@@ -118,7 +119,7 @@ var _ = Describe("(Integration) Create Managed Nodegroups", func() {
 			},
 		}),
 
-		PEntry("Ubuntu", &api.ManagedNodeGroup{
+		Entry("Ubuntu", &api.ManagedNodeGroup{
 			NodeGroupBase: &api.NodeGroupBase{
 				Name:       "ubuntu",
 				VolumeSize: aws.Int(25),
@@ -191,25 +192,24 @@ var _ = Describe("(Integration) Create Managed Nodegroups", func() {
 		}),
 	)
 
-	Context("Bottlerocket nodegroups", func() {
-		It("should work as a node AMI family", func() {
+	Describe("Bottlerocket nodegroup", func() {
+		var kubeTest *harness.Test
+
+		BeforeEach(func() {
+			var err error
+			kubeTest, err = kube.NewTest(params.KubeconfigPath)
+			Expect(err).ToNot(HaveOccurred())
+		})
+
+		AfterEach(func() {
+			kubeTest.Close()
+		})
+
+		assertCreateBottlerocket := func(ng *api.ManagedNodeGroup) *corev1.NodeList {
 			clusterConfig := makeClusterConfig()
-			clusterConfig.ManagedNodeGroups = []*api.ManagedNodeGroup{
-				{
-					NodeGroupBase: &api.NodeGroupBase{
-						Name:       "bottlerocket",
-						VolumeSize: aws.Int(35),
-						AMIFamily:  "Bottlerocket",
-					},
-					Taints: []api.NodeGroupTaint{
-						{
-							Key:    "key1",
-							Value:  "value1",
-							Effect: "PreferNoSchedule",
-						},
-					},
-				},
-			}
+			ng.Name = names.ForNodeGroup("", "")
+
+			clusterConfig.ManagedNodeGroups = []*api.ManagedNodeGroup{ng}
 			cmd := params.EksctlCreateCmd.
 				WithArgs(
 					"nodegroup",
@@ -220,6 +220,75 @@ var _ = Describe("(Integration) Create Managed Nodegroups", func() {
 				WithStdin(testutils.ClusterConfigReader(clusterConfig))
 
 			Expect(cmd).To(RunSuccessfully())
+
+			nodeList := kubeTest.ListNodes(metav1.ListOptions{
+				LabelSelector: fmt.Sprintf("%s=%s", "eks.amazonaws.com/nodegroup", ng.Name),
+			})
+			Expect(nodeList.Items).ToNot(BeEmpty())
+			for _, node := range nodeList.Items {
+				Expect(node.Status.NodeInfo.OSImage).To(ContainSubstring("Bottlerocket"))
+			}
+			return nodeList
+		}
+
+		It("should create a standard nodegroup", func() {
+			ng := &api.ManagedNodeGroup{
+				NodeGroupBase: &api.NodeGroupBase{
+					VolumeSize: aws.Int(35),
+					AMIFamily:  "Bottlerocket",
+					Labels: map[string]string{
+						"ami-family": "bottlerocket",
+					},
+					Bottlerocket: &api.NodeGroupBottlerocket{
+						EnableAdminContainer: api.Enabled(),
+					},
+					ScalingConfig: &api.ScalingConfig{
+						DesiredCapacity: aws.Int(1),
+					},
+				},
+				Taints: []api.NodeGroupTaint{
+					{
+						Key:    "key1",
+						Value:  "value1",
+						Effect: "PreferNoSchedule",
+					},
+				},
+			}
+
+			assertCreateBottlerocket(ng)
+		})
+
+		It("should create a nodegroup with custom Bottlerocket settings", func() {
+			ng := &api.ManagedNodeGroup{
+				NodeGroupBase: &api.NodeGroupBase{
+					VolumeSize: aws.Int(20),
+					AMIFamily:  "Bottlerocket",
+					Labels: map[string]string{
+						"ami-family": "bottlerocket",
+					},
+					Bottlerocket: &api.NodeGroupBottlerocket{
+						EnableAdminContainer: api.Enabled(),
+						Settings: &api.InlineDocument{
+							"motd": "Bottlerocket is the future",
+							"network": map[string]string{
+								"hostname": "custom-bottlerocket-host",
+							},
+						},
+					},
+				},
+				Taints: []api.NodeGroupTaint{
+					{
+						Key:    "key1",
+						Value:  "value1",
+						Effect: "PreferNoSchedule",
+					},
+				},
+			}
+
+			nodeList := assertCreateBottlerocket(ng)
+			for _, node := range nodeList.Items {
+				Expect(node.Labels["kubernetes.io/hostname"]).To(Equal("custom-bottlerocket-host"))
+			}
 		})
 	})
 
